@@ -23,7 +23,7 @@ def st_make_envelope(bbox):
 
     bbox_str = [str(x) for x in bbox]
 
-    pgis_bbox = "ST_MakeEnvelope(" + ",".join(bbox_str) + ", 4326)"
+    pgis_bbox = "ST_MakeEnvelope(" + ",".join(bbox_str) + ")"
 
     return(pgis_bbox)
 
@@ -39,7 +39,7 @@ def st_intersects(
 
     geo_col = table + "." + geom_col
 
-    pgis_intersects = "ST_Intersects(" + geo_col + ", '" + geom + "')"
+    pgis_intersects = "ST_Intersects(" + geo_col + ", ST_GeomFromText('" + geom + "', 4326))"
 
     return(pgis_intersects)
 
